<?php
namespace Teknisa\MAN\Controllers;

use Teknisa\MAN\Services\CadAmbienteService;
use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DB\StorageProcedure\Param;

class CadAmbiente extends CrudWithParameterBag {

    protected $dataSourceName = 'cadAmbiente';
    /**
     * @var CadAmbienteService
     */
    protected $cadAmbienteService;
    protected $parameterBagColumns = array('P_NRORG');

    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, CadAmbienteService $cadAmbienteService) {
        $this->cadAmbienteService = $cadAmbienteService;        
        parent::__construct($dataSourceManager,$parameterBag);
    }

    public function save(DTO\Request\DataSet $request, DTO\Response $response) {
        $this->dataSourceName='cadAmbienteSave';
        foreach($request->getDataSet()->getRows() as &$row) {
            if($row['__is_new'] && (!isset($row['CDSALA']) || !is_int($row['CDSALA']))) {                
                $row['CDFILIAL'] = $row['PARENT'];
                $row['CDSALA'] = $this->cadAmbienteService->getNextCodigo($row['CDFILIAL']);                                 
            }
        }
        try {
            $dataSet = $request->getDataSet();
            $dataSet->setDataSourceName($this->dataSourceName);
            $persistedRows = $this->dataSourceManager->persist($dataSet);
            $response->addDataSet(new DataSet($this->dataSourceName, $persistedRows));
            $nrPersistedRows = count($persistedRows);
            $response->addNotification(new Notification("{$nrPersistedRows} row(s) persisted with success", Notification::TYPE_SUCCESS));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function findCodigo(DTO\Request\DataSet $request, DTO\Response $response){
        $i = $request->getDataSet()->getRows();
        foreach ($i as $row) {
            $sgsala = $row['SGSALA'];
            $nrorg = $row['NRORG'];
            $retorno = $this->cadAmbienteService->findCodigo($sgsala, $nrorg);
        }
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('cadAmbienteFindCodigo', $retorno));
    }
}